@@ -46,8 +46,11 @@ function home_inputrc () {
 function home_profiles () {
   if sudo -u "${1}" tee "${2}" >/dev/null <<EOT; then
 # shellcheck disable=SC1090
-if [[ -f ~/.bashrc ]]; then
-  . ~/.bashrc
+PATH='/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin:/bin:/sbin:.'
+if [ "${BASH-no}" != "no" ]; then
+  if [[ -f ~/.bashrc ]]; then
+    . ~/.bashrc
+  fi
 fi
 EOT
     info.sh homefiles "${2}"
